AppEnvironment class

Constructors

AppEnvironment()

Properties

getEnvironment Environments
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCoreApiBaseUrl() String?
getSnapApiBaseUrl() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnvironment(Environments value) Environments
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited