CustomerDetails class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CustomerDetails({String? firstName, String? lastName, String? email, String? phone, Address? billingAddress, Address? shippingAddress})
CustomerDetails.fromJson(Map<String, dynamic> json)
factory

Properties

billingAddress Address?
final
email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
lastName String?
final
phone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress Address?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited