FreeText class

Annotations
  • @JsonSerializable.new()

Constructors

FreeText({List<LanguageText>? inquiry, List<LanguageText>? payment})
FreeText.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inquiry List<LanguageText>?
final
payment List<LanguageText>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited