ItemDetails class

Annotations
  • @JsonSerializable.new()

Constructors

ItemDetails({String? id, int? price, int? quantity, String? name, String? brand, String? category, String? merchantName, String? url})
ItemDetails.fromJson(Map<String, dynamic> json)
factory

Properties

brand String?
final
category String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
merchantName String?
final
name String?
final
price int?
final
quantity int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited