Va class

Annotations
  • @JsonSerializable.new()

Constructors

Va({String? vaNumber, String? subCompanyCode, FreeText? freeText, String? recipientName})
Va.fromJson(Map<String, dynamic> json)
factory

Properties

freeText FreeText?
final
hashCode int
The hash code for this object.
no setterinherited
recipientName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCompanyCode String?
final
vaNumber String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited