MidtransClientRemote class abstract

Annotations
  • @RestApi.new()

Constructors

MidtransClientRemote(Dio dio, {String baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

charge(TransactionRequest body) Future<ChargeSuccessResponse>
Charge a transaction required body parameter type TransactionRequest , return ChargeSuccessResponse or throw DioException
getSnapToken(TransactionRequest body) Future<SnapSuccessResponse>
Get Snap Token required body parameter type TransactionRequest , return SnapSuccessResponse or throw DioException
getTransactionStatus(String orderId) Future<TransactionStatusResponse>
Get Transaction Status required orderId parameter type String , return TransactionStatusResponse or throw DioException
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createClient({Map<String, dynamic> headers = const {}, int connectTimeout = 30000, int receiveTimeout = 30000, required String baseUrl}) MidtransClientRemote