MidtransClientRemote class abstract
- Annotations
-
- @RestApi.new()
Constructors
- MidtransClientRemote(Dio dio, {String baseUrl})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
charge(
TransactionRequest body) → Future< ChargeSuccessResponse> -
Charge a transaction required
bodyparameter type TransactionRequest , return ChargeSuccessResponse or throwDioException -
getSnapToken(
TransactionRequest body) → Future< SnapSuccessResponse> -
Get Snap Token required
bodyparameter type TransactionRequest , return SnapSuccessResponse or throwDioException -
getTransactionStatus(
String orderId) → Future< TransactionStatusResponse> -
Get Transaction Status required
orderIdparameter type String , return TransactionStatusResponse or throwDioException -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createClient(
{Map< String, dynamic> headers = const {}, int connectTimeout = 30000, int receiveTimeout = 30000, required String baseUrl}) → MidtransClientRemote